@@ -10,10 +10,13 @@ from django.conf import settings
 # -- Loading base models
 
 admin.site.register(LinkProperty)
+admin.site.register(Link)
 admin.site.register(Role)
 admin.site.register(PersonCategory)
 admin.site.register(Person, PersonAdmin)
 admin.site.register(Organization, OrganizationAdmin)
+admin.site.register(OrganizationCategory)
+admin.site.register(OrgRelationType)
 admin.site.register(SitePrefs, SitePrefsAdmin)
 
 
