@@ -51,6 +51,8 @@ TEMPLATE_LOADERS = [
     'django.template.loaders.filesystem.Loader',
     'django.template.loaders.app_directories.Loader',
 #     'django.template.loaders.eggs.Loader',
+    'apptemplates.Loader',
+
 ]
 
 MIDDLEWARE_CLASSES = [
@@ -139,6 +141,9 @@ INSTALLED_APPS = [
     'slugify',
     'forms_builder.forms',
     'preferences',
+    'apptemplates',
+    'scanredirect',
+
 
     # WebID
     #'django_webid.provider',
@@ -150,12 +155,13 @@ INSTALLED_APPS = [
     # 'feincms',  # for their MPTT tree editor, not synced
     'coop',  # override feincms tree editor template
     'coop.link',
+    'coop.prefs',
     'coop.org',
     'coop.person',
     'coop.ui',
     #'coop.webid',
 
-    #'coop_geo',
+    'coop_geo',
 
     # PuSH
     'django_rq',
@@ -217,20 +223,15 @@ DJALOHA_LINK_MODELS = (
 # COOP_CMS_ARTICLE_TEMPLATES = 'coop_local.get_article_templates' # marche plus ?
 
 COOP_CMS_ARTICLE_TEMPLATES = [
-    ('coop_cms/article_standard.html', 'Standard'),
-    ('coop_cms/article_standard.html', 'Article sans logo'),
-    ('coop_cms/article_rubrique.html', 'Rubrique'),
+    ('coop_cms/article.html', 'Standard'),
+    ('coop_cms/article_nologo.html', 'Sans logo'),
 ]
 
+
+SKIP_DJALOHA_JQUERY = True
+
 FORMS_BUILDER_USE_SITES = False
 
-HAYSTACK_SITECONF = 'coop_local.search_sites'
-HAYSTACK_SEARCH_ENGINE = 'simple'
-HAYSTACK_CONNECTIONS = {
-    'default': {
-        'ENGINE': 'haystack.backends.simple_backend.SimpleEngine',
-    },
-}
 
 ADMIN_TOOLS_MENU = 'coop.ui.menu.CustomMenu'
 ADMIN_TOOLS_INDEX_DASHBOARD = 'coop.ui.dashboard.CustomIndexDashboard'
@@ -337,11 +338,11 @@ LOGGING = {
         },
         'subhub.maintenance': {
             'handlers': ['console'],
-            'level': 'DEBUG'
+            'level': 'ERROR'
         },
         'subhub.distribution.process': {
             'handlers': ['console'],
-            'level': 'DEBUG'
+            'level': 'ERROR'
 
         },
         'worker': {
@@ -351,7 +352,7 @@ LOGGING = {
         },
         'coop': {
             'handlers': ['console-dumb'],
-            'level': 'DEBUG',
+            'level': 'ERROR',
         },
     },
 
