@@ -16,6 +16,8 @@ from coop_local.urls import urlpatterns
 handler500 = 'coop.views.SentryHandler500'
 
 urlpatterns += patterns('',
+    
+    url(r'^', include('scanredirect.urls')),
 
     #Testing webid urls
     # url(r'^accounts/webidauth', 'coop.webid.views.test_login',
@@ -60,7 +62,7 @@ urlpatterns += patterns('',
 
 
 # for local testing
-if settings.DEBUG or ('test' in sys.argv) or ('runserver' in sys.argv):
+if settings.DEBUG:
     urlpatterns += staticfiles_urlpatterns()
     urlpatterns += patterns('',
         (r'^media/(?P<path>.*)$', 'django.views.static.serve', {'document_root': settings.MEDIA_ROOT, 'show_indexes': True}),
@@ -77,6 +79,11 @@ if 'coop.agenda' in settings.INSTALLED_APPS:
         (r'^', include('coop.agenda.urls')),
     )
 
+if 'coop.mailing' in settings.INSTALLED_APPS:
+    urlpatterns += patterns('',
+        (r'^', include('coop.mailing.urls')),
+    )
+
 urlpatterns += patterns('',
     (r'^forms/', include('forms_builder.forms.urls')),
     (r'^id/', include('uriredirect.urls')),
