@@ -46,6 +46,7 @@ class ContactInline(GenericTabularInline):
     model = get_model('coop_local', 'Contact')
     verbose_name = _(u'Contact information')
     verbose_name_plural = _(u'Contact informations')
+    fields = ('contact_medium', 'content', 'details', 'display')
     extra = 1
 
 
@@ -64,8 +65,8 @@ class RelationInline(InlineAutocompleteAdmin):
     model = get_model('coop_local', 'Relation')
     fk_name = 'source'
     readonly_fields = ('created',)
-    fields = ('reltype', 'target', 'created')
-    related_search_fields = {'target': ('title', 'subtitle', 'acronym', 'description'), }
+    fields = ('relation_type', 'target', 'created')
+    related_search_fields = {'target': ('title', 'subtitle', 'acronym',), }
     extra = 1
 
 
@@ -75,7 +76,7 @@ class OrgInline(InlineAutocompleteAdmin):
     verbose_name_plural = _(u'Engagements')
     fields = ('organization', 'role', 'role_detail', 'engagement_display')
 
-    related_search_fields = {'organization': ('title', 'subtitle', 'acronym', 'description'), }
+    related_search_fields = {'organization': ('title', 'subtitle', 'acronym',), }
     extra = 1
 
 
@@ -99,8 +100,9 @@ class OrganizationAdminForm(forms.ModelForm):
             Q(content_type=ContentType.objects.get(model='organization'), object_id=self.instance.id)
           | Q(content_type=ContentType.objects.get(model='person'), object_id__in=members_id)
             )
+        phone_categories = [1, 2]
         self.fields['pref_email'].queryset = org_contacts.filter(category=8)
-        self.fields['pref_phone'].queryset = org_contacts.filter(category=1)
+        self.fields['pref_phone'].queryset = org_contacts.filter(category__in=phone_categories)
         self.fields['category'].help_text = None
 
         member_locations_id = [m.location.id for m in
