@@ -3,7 +3,7 @@ from django.contrib.auth.models import User
 from django.db import models
 from django_extensions.db import fields as exfields
 from django.utils.translation import ugettext_lazy as _
-from django.core.urlresolvers import reverse
+from django.core.urlresolvers import reverse_lazy
 from django.template.defaultfilters import slugify
 from django.contrib.contenttypes import generic
 from django.contrib.sites.models import Site
@@ -11,6 +11,7 @@ from django.conf import settings
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.contenttypes import generic
 from coop.models import URIModel
+import rdflib
 
 if "coop_geo" in settings.INSTALLED_APPS:
     from coop_geo.models import Location
@@ -35,8 +36,6 @@ from coop.org.models import DISPLAY
 class BasePerson(URIModel):
     user = models.OneToOneField(User, blank=True, null=True, unique=True, verbose_name=_(u'django user'), editable=False)
     username = models.CharField(blank=True, max_length=100, unique=True)
-    #pour D2RQ et poura voir des URI clean meme pour des non-users
-
     category = models.ManyToManyField('coop_local.PersonCategory', blank=True, null=True, verbose_name=_(u'category'))
     last_name = models.CharField(_(u'last name'), max_length=100)
     first_name = models.CharField(_(u'first name'), max_length=100, null=True, blank=True)
@@ -44,9 +43,12 @@ class BasePerson(URIModel):
     email = models.EmailField(_(u'personal email'), blank=True, help_text=_(u'will not be displayed on the website'))
     email_sha1 = models.CharField(_(u'email checksum'), max_length=250, blank=True, null=True)
     notes = models.TextField(_(u'notes'), blank=True, null=True)
+
     structure = models.CharField(blank=True, max_length=100)
 
-    subs = generic.GenericRelation('coop_local.Subscription')
+
+    if 'coop.mailing' in settings.INSTALLED_APPS:
+        subs = generic.GenericRelation('coop_local.Subscription')
 
     if "coop_geo" in settings.INSTALLED_APPS:
         location = models.ForeignKey(Location, null=True, blank=True, verbose_name=_(u'location'))
@@ -61,10 +63,9 @@ class BasePerson(URIModel):
     def __unicode__(self):
         return unicode('%s %s' % (self.first_name, self.last_name))
 
-    @models.permalink
+    #@models.permalink
     def get_absolute_url(self):
-        return reverse('profiles_profile_detail', args=[self.username])
-        #return ('profiles_profile_detail', (), {'username': self.username})
+        return reverse_lazy('coop.person.views.public_profile', kwargs={'uuid': self.uuid})
 
     def has_user_account(self):
         return (self.user != None)
@@ -94,9 +95,14 @@ class BasePerson(URIModel):
 
         # create username slug if not set
         if self.username == '':
+            from coop_local.models import Person
             newname = slugify(self.first_name).replace('-', '_') + '.' + \
                         slugify(self.last_name).replace('-', '_')
+            if Person.objects.filter(username=newname).exists():
+                offset = Person.objects.filter(username=newname).count()
+                newname = newname + '_' + str(offset + 1)
             self.username = newname
+
         # synchronize fields with django User model
         if self.user:
             chg = False
@@ -107,3 +113,40 @@ class BasePerson(URIModel):
             if(chg):
                 self.user.save()
         super(BasePerson, self).save(*args, **kwargs)
+
+
+    # RDF stuf
+    rdf_type = settings.NS.person.Person
+    base_mapping = [
+        ('single_mapping', (settings.NS.dct.created, 'created'), 'single_reverse'),
+        ('single_mapping', (settings.NS.dct.modified, 'modified'), 'single_reverse'),
+        ('single_mapping', (settings.NS.foaf.familyName, 'last_name'), 'single_reverse'),
+        ('single_mapping', (settings.NS.foaf.givenName, 'first_name'), 'single_reverse'),
+        ('single_mapping', (settings.NS.foaf.mbox_sha1sum, 'email_sha1'), 'single_reverse'),
+        ('single_mapping', (settings.NS.skos.note, 'notes'), 'single_reverse'),
+ 
+        ('multi_mapping', (settings.NS.dct.subject, 'tags'), 'multi_reverse'),
+        ('multi_mapping', (settings.NS.ess.hasContactMedium, 'contact'), 'multi_reverse'),
+
+        ('name_mapping', (settings.NS.foaf.name, 'username'), 'name_mapping_reverse'),
+        ('location_mapping', (settings.NS.locn.location, 'location'), 'location_mapping_reverse')
+
+    ]
+
+    def name_mapping(self, rdfPred, djF, lang=None):
+        if (self.first_name == "" or self.first_name == None) and self.last_name == "":
+            return [(rdflib.term.URIRef(self.uri), rdfPred, rdflib.term.Literal(self.username, lang))]
+        else:
+            return [(rdflib.term.URIRef(self.uri), rdfPred, rdflib.term.Literal(u"%s %s" % (self.first_name, self.last_name), lang))]
+
+    def name_mapping_reverse(self, g, rdfP, djF, lang=None):
+        pass
+
+    def location_mapping(self, rdfPred, djF, lang=None):
+        if hasattr(self, 'location_display') and self.location_display == DISPLAY.PUBLIC:
+            if self.location:
+                return[(rdflib.term.URIRef(self.uri), rdfPred, rdflib.term.URIRef(self.location.uri))]
+        return []
+
+    def location_mapping_reverse(self, g, rdfP, djF, lang=None):
+        pass
