@@ -1,9 +1,6 @@
 # -*- coding:utf-8 -*-
 
-from coop_local.settings import PROJECT_PATH, PROJECT_NAME
-
-
-# Not used: to set this variable here, weneed to import Site
+# Not used: to set this variable here, we need to import Site
 PUSH_HUB = ''
 SUBHUB_MAINTENANCE_AUTO = False
 
@@ -32,10 +29,12 @@ BASE_COOP_LOCAL_MODELS = [
         u'PersonCategory',
     ]),
     ('coop.org', [
+        u'ContactMedium',
         u'Contact',
         u'Engagement',
         u'Role',
         u'RoleCategory',
+        u'OrgRelationType',
         u'Relation',
         u'OrganizationCategory',
         u'Organization',
@@ -73,6 +72,8 @@ RDF_NAMESPACES = {
  'ctag': u'http://commontag.org/ns#',
  'd2rq': u'http://www.wiwiss.fu-berlin.de/suhl/bizer/D2RQ/0.1#',
  'dct': u'http://purl.org/dc/terms/',
+ 'dce': u'http://purl.org/dc/elements/1.1/',
+ 'dcmi': u'http://purl.org/dc/dcmitype/',
  'ess':  u'http://ns.economie-solidaire.fr/ess#',
  'event': u'http://purl.org/NET/c4dm/event.owl#',
  'foaf': u'http://xmlns.com/foaf/0.1/',
@@ -91,12 +92,12 @@ RDF_NAMESPACES = {
  'sioc': u'http://rdfs.org/sioc/ns#',
  'skos': u'http://www.w3.org/2004/02/skos/core#',
  'skosxl': u'http://www.w3.org/2008/05/skos-xl#',
- 'vcal': u'http://www.w3.org/2002/12/cal/icaltzd#Vcalendar',
+ 'vcal': u'http://www.w3.org/2002/12/cal/icaltzd#',
  'vcard': u'http://www.w3.org/2006/vcard/ns#',
  'xsd': 'http://www.w3.org/2001/XMLSchema#',
  }
 
 
-NS = AttributeDict( transform_dict(RDF_NAMESPACES).items() )
+# NS = AttributeDict( transform_dict(RDF_NAMESPACES).items() )
 
 
