@@ -1,6 +1,7 @@
 # -*- coding:utf-8 -*-
 
 from django.conf import settings
+import sys
 
 # Here you can override any settings from coop default settings files
 # See :
@@ -9,13 +10,15 @@ from django.conf import settings
 
 SITE_AUTHOR = 'Organisme'
 SITE_TITLE = 'Demo Django-coop'
-DEFAULT_URI_DOMAIN = '{{ domain }}'
-
-D2RQ_PORT = 8080
-D2RQ_ROOT = 'http://{{ domain }}:8080/' + settings.PROJECT_NAME + '/'
-
+# DEFAULT_URI_DOMAIN = '{{ domain }}' useless use Site.objects.get_current().domain instead
 
+# let this setting to False in production, except for urgent debugging
 DEBUG = False
+
+# Force DEBUG setting if we're developing locally or testing
+if 'runserver' in sys.argv or 'test' in sys.argv:
+    DEBUG = True
+
 TEMPLATE_DEBUG = DEBUG
 
 ADMINS = (
@@ -24,12 +27,16 @@ ADMINS = (
 
 MANAGERS = ADMINS
 SEND_BROKEN_LINK_EMAILS = True
-INTERNAL_IPS = ('127.0.0.1', '92.243.30.98')
+# INTERNAL_IPS = ('127.0.0.1', '92.243.30.98')
 
 SUBHUB_MAINTENANCE_AUTO = False    # set this value to True to automatically syncronize with agregator
 PES_HOST = 'pes.domain.com'
 THESAURUS_HOST = 'thess.domain.com'
 
+# Need to be set to true, when domain stop moving,
+# to keep history of renaming of uri
+URI_FIXED = False  
+
 INSTALLED_APPS = settings.INSTALLED_APPS + [
     # select your coop components
     'coop.tag',
@@ -41,15 +48,14 @@ INSTALLED_APPS = settings.INSTALLED_APPS + [
     'coop_local',
      # coop optional modules
     'coop_geo',  # est obligatoirement APRES coop_local
-
 ]
 
 # TODO: to be discuss this settings could be in default_project_setings.py
 # file. To be check I knew more on how to configure sympa
 SYMPA_SOAP = {
-    'WSDL': 'http://sympa.{{ domain }}/sympa/wsdl',
+    'WSDL': 'http://sympa.{{ root_domain }}/sympa/wsdl',
     'APPNAME': 'djangoapp',
     'PASSWORD': 'test',
-    'OWNER': 'USER_EMAIL=userProxy@my.server',
+    'OWNER': ADMINS[0][1],
     'PARAMETER_SEPARATOR': '__SEP__',      # used for template
 }
