@@ -15,12 +15,13 @@ urlpatterns = patterns('',
 
     url(r'^$', 'coop.views.home', name="home"),
 
-    (r'^org/', include('coop.org.urls')),
-    (r'^comments/', include('django.contrib.comments.urls')),
+    url(r'^org/', include('coop.org.urls')),
+    url(r'^geojson/(?P<what>[\w-]+)/(?P<criteria>[\w-]+)/$', 'coop.views.geojson_objects'),
+
+    url(r'^comments/', include('django.contrib.comments.urls')),
 
     # a revoir
-    (r'^perso/$', 'coop.person.views.perso'),
-    (r'^membre/', include('coop.person.urls')),
+    (r'^profil/', include('coop.person.urls')),
 
     url(r'^feed/(?P<model>[\w-]+)/$', UpdateFeed()),
     url(r'^hub/', include('subhub.urls')),
@@ -28,16 +29,21 @@ urlpatterns = patterns('',
 
     url(r'^robots\.txt$', TextPlainView.as_view(template_name='robots.txt')),
     url(r'^favicon\.ico$', RedirectView.as_view(url='/static/img/favicon.ico')),
-    url(r'^d2r/(?P<mode>[\w-]+)/mapping.ttl$', 'coop.views.d2r_mapping'),
+    url(r'^rdfdump/(?P<model>[\w-]+).(?P<format>[\w-]+)$', 'coop.views.rdfdump'),
+
+    # url(r'^d2r/(?P<mode>[\w-]+)/mapping.ttl$', 'coop.views.d2r_mapping'),
+
+    url(r'^communes/$', 'coop.views.communes'),
+    url(r'^geojson/', 'coop.views.geojson'),
 
 )
 
 if 'coop.exchange' in settings.INSTALLED_APPS:
     urlpatterns = urlpatterns + patterns('',
         (r'^annonces/', include('coop.exchange.urls')),
-    )
+)
 
 if 'coop.webid' in settings.INSTALLED_APPS:
     urlpatterns = urlpatterns + patterns('',
         (r'^webid/', include('coop.webid.urls')),
-    )
\ No newline at end of file
+)
