@@ -1,3 +1,5 @@
+# -*- coding:utf-8 -*-
+
 #
 #    Autocomplete feature for admin panel
 #
@@ -89,7 +91,6 @@ class FkSearchInput(ForeignKeyRawIdWidget):
             'all': ('autocomplete/css/jquery.autocomplete.css',)
         }
         js = (
-            #'autocomplete/js/jquery.js',
             'autocomplete/js/jquery.bgiframe.min.js',
             'autocomplete/js/jquery.ajaxQueue.js',
             'autocomplete/js/jquery.autocomplete.js',
@@ -129,13 +130,14 @@ class FkSearchInput(ForeignKeyRawIdWidget):
         context = {
             'url': url,
             'related_url': related_url,
-            'admin_media_prefix': settings.ADMIN_MEDIA_PREFIX,
+            #'admin_media_prefix': settings.ADMIN_MEDIA_PREFIX,
             'search_path': self.search_path,
             'search_fields': ','.join(self.search_fields),
             'model_name': model_name,
             'app_label': app_label,
             'label': label,
             'name': name,
+            'remote_search_path': 'http://' + settings.PES_HOST + '/suggestions/',
         }
 
 
@@ -168,7 +170,6 @@ class NoLookupsForeignKeySearchInput(ForeignKeyRawIdWidget):
             'all': ('autocomplete/css/jquery.autocomplete.css',)
         }
         js = (
-            #'autocomplete/js/jquery.js',
             'autocomplete/js/jquery.bgiframe.min.js',
             'autocomplete/js/jquery.ajaxQueue.js',
             'autocomplete/js/jquery.autocomplete.js',
@@ -209,13 +210,15 @@ class NoLookupsForeignKeySearchInput(ForeignKeyRawIdWidget):
         context = {
             'url': url,
             'related_url': related_url,
-            'admin_media_prefix': settings.ADMIN_MEDIA_PREFIX,
+            #'admin_media_prefix': settings.ADMIN_MEDIA_PREFIX,
             'search_path': self.search_path,
             'search_fields': ','.join(self.search_fields),
             'model_name': model_name,
             'app_label': app_label,
             'label': label,
             'name': name,
+            'remote_search_path': 'http://' + settings.PES_HOST + '/suggestions/',
+
         }
 
 # tried to change widget_template but it needs a subclass (of what?) not a string
@@ -246,7 +249,6 @@ class InlineSearchInput(ForeignKeyRawIdWidget):
             'all': ('autocomplete/css/jquery.autocomplete.css',)
         }
         js = (
-            #'autocomplete/js/jquery.js', # plus besoin avec 1.3 et django.jQuery
             'autocomplete/js/jquery.bgiframe.min.js',
             'autocomplete/js/jquery.ajaxQueue.js',
             'autocomplete/js/jquery.autocomplete.js',
@@ -287,13 +289,15 @@ class InlineSearchInput(ForeignKeyRawIdWidget):
         context = {
             'url': url,
             'related_url': related_url,
-            'admin_media_prefix': settings.ADMIN_MEDIA_PREFIX,
+            #'admin_media_prefix': settings.ADMIN_MEDIA_PREFIX,
             'search_path': self.search_path,
             'search_fields': ','.join(self.search_fields),
             'model_name': model_name,
             'app_label': app_label,
             'label': label,
             'name': name,
+            'remote_search_path': 'http://' + settings.PES_HOST + '/suggestions/',
+
         }
 
 # tried to change widget_template but it needs a subclass (of what?) not a string
@@ -525,14 +529,24 @@ class NoLookupsFkAutocompleteAdmin(admin.ModelAdmin):
         return HttpResponseNotFound()
 
     def get_help_text(self, field_name, model_name):
-        searchable_fields = self.related_search_fields.get(field_name, None)
-        if searchable_fields:
-            help_kwargs = {
-                'model_name': model_name,
-                'field_list': get_text_list(searchable_fields, _('and')),
-            }
-            return _('Use the left field to do %(model_name)s lookups in the fields %(field_list)s.') % help_kwargs
-        return ''
+        #import pdb; pdb.set_trace()
+        help_vars = {'field': field_name}
+        return _(u"""<select class="input_method_select" id="%(field)s_input_method" style="margin-right:20px;">
+                     <option value="key">Rechercher sur ce site</option>
+                     <option value="pes">Rechercher sur la PES</option>
+                     <option value="txt">Indiquer juste le nom</option>
+                     </select>&nbsp;&nbsp;&nbsp;
+                        """) % help_vars
+
+
+        # searchable_fields = self.related_search_fields.get(field_name, None)
+        # if searchable_fields:
+        #     help_kwargs = {
+        #         'model_name': model_name,
+        #         'field_list': get_text_list(searchable_fields, _('and')),
+        #     }
+        #     return _('Use the left field to do %(model_name)s lookups in the fields %(field_list)s.') % help_kwargs
+        # return ''
 
 
 # this method gets called when creating the formfields - probably this is what you need to extend
